import { Input, Component, Inject } from 'ng-metadata/core';
import { ApostilleSignatureDocument, ApostilleTagDocument } from '../../../types/common.types';
import * as moment from "moment";

/**
 * A component that displays the signing status of a tag in the repository view.
 */
@Component({
  selector: 'tag-signing-display',
  templateUrl: '/static/js/directives/ui/tag-signing-display/tag-signing-display.component.html',
})
export class TagSigningDisplayComponent {
  @Input('<') public tag: any;
  @Input('<') public signatures: ApostilleSignatureDocument;

  private signedDigest: string;
  private pushedDigest: string;

  constructor(@Inject("$sanitize") private $sanitize: ng.sanitize.ISanitizeService) {}

  private base64ToHex(base64String: string): string {
    // Based on: http://stackoverflow.com/questions/39460182/decode-base64-to-hexadecimal-string-with-javascript
    var raw = atob(base64String);
    var hexString = '';
    for (var i = 0; i < raw.length; ++i) {
      var char = raw.charCodeAt(i);
      var hex = char.toString(16)
      hexString += (hex.length == 2 ? hex : '0' + hex);
    }
    return hexString;
  }

  private expirationStatus(tag: any, signatures: ApostilleSignatureDocument): string {
    if (!signatures || !signatures.expiration) {
      return 'unknown';
    }

    var expires = moment(signatures.expiration);
    var now = moment();

    if (expires.isSameOrBefore(now)) {
      return 'expired';
    }

    var withOneWeek = moment().add('1', 'w');
    if (expires.isSameOrBefore(withOneWeek)) {
      return 'expires-soon';
    }

    return 'okay';
  }

  private signingStatus(tag: any, signatures: ApostilleSignatureDocument): string {
    if (!tag || !signatures) {
      return 'loading';
    }

    if (signatures.error || !signatures.tags) {
      return 'error';
    }

    var tag_info = signatures.tags[tag.name];
    if (!tag_info || !tag.manifest_digest) {
      return 'not-signed';
    }

    var digest_without_prefix = tag.manifest_digest.substr('sha256:'.length);
    var hex_signature = this.base64ToHex(tag_info.hashes['sha256']);

    if (hex_signature == digest_without_prefix) {
      return 'valid-signature';
    } else {
      this.signedDigest = this.$sanitize(hex_signature);
      this.pushedDigest = this.$sanitize(digest_without_prefix);
      return 'invaid-signature';
    }
  }
}